# 数据库设计

## 数据库表结构

### 数据列结构

#### 数据列定义组成

数据列元数据结构如下：

- 编号：数据列的唯一标识，采用全局统一的 5 段 10 位编码；

- 数据列名：通常由中文简称的汉语拼音首字母（大写）组成，与中文简称一一对应，宜在实际数据结构中采用；

- 中文简称：所用的数据元素的名称，具有语义，面向用户；

- 类型：数据列容纳的数据类型，本标准在数据列中简称其为类型（一种属性）；

- 长度：数据列能容纳的最大字符数（一种属性）；

- 约束：数据列约束状态的描述，即必备数据列或可选数据列（一种属性）；

- 值空间：数据列取值的范围与规范（一种属性）；

- 解释/举例：数据列属性的说明或举例；

- 引用编号：指明此数据列引用其他已定义数据列的编号。

### 数据列名

数据列名通常由“中文简称”每个汉字的拼音首字母（大写）组成，且与其一一对应，宜在实际数据结构中采用。

### 数据类型

#### 字符型

字符型为 C（－Character），在信息系统中取用时，可以是可变长度，如 VARCHAR2 （Oracle）或 NVARCHAR（SQL Server）。 日期：采用 GB/T 7408 中的日期完全表示法，字符型，中间不加符号，格式：YYYYMMDD。 时间：采用 GB/T 7408 中的时间完全表示法，字符型，中间不加符号，格式：hhmmss。

#### 数值型

数值型为 N（－Number），可参与运算。

####　币值型

币值型为 M（－Money），定义了金额属性的结构对象，此结构包括 3 个域：“币种”、“单位”和“金额”。默认定义币种为：人民币，单位：元（需要时也可定义为：万元），总长度：不定长，小数后长度：4 位，取值范围：数字。需要时，M 可依照 GB/T 12406 定义为其他币种。

#### 二进制类型

二进制类型为 B（－Binary），宜在照片或超长文本采用。

#### 文本型

文本型为 T（－Text），宜用于数量较多的文字描述。本标准约定长度大于 200 字符时采用文本型 T。

#### 布尔型

布尔型为 BL（—Boolean）。

#### 时间戳类型

时间戳类型 TS（Timestamp）。

#### 约束

可选数据元素 O（Optional data element）：在数据类/子类中定义，但不是必须在数据结构的实例中出现的数据元素。必备数据元素 M（Madatory data element）：在数据类/子类中定义，应在数据结构的实例中出现的数据元素。符合以下三条原则之一的数据列为必备数据元素（M）：

- 在该管理数据类或子类中不可或缺的数据列（元素）；
- 在标准针对的教育管理范围内，跨管理业务域的应用系统之间需要交换、共享的数据列；
- 需要满足上级部门统计要求或交换的数据列。

#### 值空间

数据元素取值的格式、范围与规范。凡是可以代码化的，应采用代码。

#### 编号

数据元素的编号方式表示了数据元素的层次结构及其组成成分。采用全局统一的 5 段 10 位编码，编号由前 4 位字母和后 6 位数字组成。第 1、2 位的字母代表本标准体系中规定的标准简称（EMGI 简 称 JC），第 3、4 位的字母代表数据子集的简称，第 5、6 位的数字代表数据类，第 7、8 位的数字代表数据子类，最后 2 位的数字代表数据子类中数据元素的编号，从小到大顺序排列，数据元素的编号在全标准体系内唯一。

#### 取用编号

为避免数据冗余，当前数据列如与本标准中已定义的数据列含义及格式相同，则应“取用”已定义的数据列。“取用”的描述规则为：当前数据列的编号、数据列名、中文简称采用被取用数据元素的编号、数据列名、中文简称；“类型”、“长度”缺省；“约束”条件应按本数据类/子类需求重新确认(M/O）。取用数据元素之后，下一个数据元素的编号接续当前数据元素的上一个数据元素编号编排。“取用”具有广义性，需要时当前数据类/子类可以整体取用本标准已经定义的数据类/子类。

##### 引用编号

为避免数据冗余，当前数据列可“引用”本标准中其他同义数据元素的格式。“引用”的描述规则为：在“引用编号”中列出被引用的数据元素的编号；“类型”、“长度”缺省；“约束”条件应按本数据类/子类需求重新确认(M/O）。

## 账号数据表 （ACCOUNT）

本数据类规定了账号的基本数据项。

| 数据列名 | 中文简称 | 类型 | 长度 | 约束 | 值空间                | 解释/举例          |
| -------- | -------- | ---- | ---- | ---- | --------------------- | ------------------ |
| DLM      | 登录名   | C    | 36   | M    |
| MM       | 密码     | C    | 18   | M    |
| XM       | 姓名     | C    | 36   | M    |
| JS       | 角色     | C    | 2    | M    | 01:管理员,02 普通用户 |                    |
| LXFS     | 联系方式 | C    | 36   | O    |                       | 手机号码、电话号码 |
